weblogolib.LogoData

Package weblogolib :: Class LogoData |

# Class LogoData

source code

    object --+
             |
            LogoData

    The data needed to generate a sequence logo.

    - alphabet
    - length
    - counts  -- An array of character counts
    - entropy -- The relative entropy of each column
    - entropy_interval -- entropy confidence interval

Instance Methods
__init__(self, length=None, alphabet=None, counts=None, entropy=None, entropy_interval=None, weight=None) Creates a new LogoData object | source code
__str__(self) str(x) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods
from_counts(cls, alphabet, counts, prior=None) Build a LogoData object from counts. | source code
from_seqs(cls, seqs, prior=None) Build a LogoData object from a SeqList, a list of sequences. | source code

Properties
Inherited from `object`: `__class__`

Method Details

### __init__(self, length=None, alphabet=None, counts=None, entropy=None, entropy_interval=None, weight=None) (Constructor) | source code
    Creates a new LogoData object
Overrides: object.__init__

### __str__(self) (Informal representation operator) | source code
    str(x)
Overrides: object.__str__ (inherited documentation)